@@ -58,8 +58,6 @@ class PlatformJsonDateTime(datetime.datetime):
     @staticmethod
     def str2components(v: str) -> tuple[int, int, int, int, int, int, int]:
         return (int(v[:4]), *(int(v[_:_+2]) for _ in range(4, 14, 2)))
-    # def __repr__(self):
-    #     return super().__repr__()})'
     
     def __str__(self):
         return np_config.normalize_time(self)
@@ -101,6 +99,7 @@ class PlatformJson(pydantic.BaseModel):
             logger.debug("Loading from existing %s", self.path.name)
         else:
             logger.debug("Creating new %s", self.path.name)
+            self.platform_json_creation_time = np_config.normalize_time(time.time())
         self.load_from_existing()
         
     def __str__(self):
@@ -166,7 +165,8 @@ class PlatformJson(pydantic.BaseModel):
         return v
 
     _foraging_id_re: ClassVar[str] = (
-        r"([0-9,a-f]{8}-[0-9,a-f]{4}-[0-9,a-f]{4}-[0-9,a-f]{4}-[0-9,a-f]{12})"
+        r"([0-9,a-f]{8}-[0-9,a-f]{4}-[0-9,a-f]{4}-[0-9,a-f]{4}-[0-9,a-f]{12})" \
+        r"|([0-9,a-f]{8})"
     )
     
     # auto-generated / ignored ------------------------------------------------------------- #
@@ -174,10 +174,11 @@ class PlatformJson(pydantic.BaseModel):
     "Updated on write."
     rig_id: Optional[str] = np_config.Rig().id if np_config.RIG_IDX else None
     wfl_version: float = 0
-    platform_json_creation_time: PlatformJsonDateTime = pydantic.Field(
-        default_factory=lambda: np_config.normalize_time(time.time()),
-        validate=PlatformJsonDateTime.validate,
-    )
+    platform_json_creation_time: Union[PlatformJsonDateTime, str] = ""
+    # = pydantic.Field(
+    #     default_factory=lambda: np_config.normalize_time(time.time()),
+    #     validate=PlatformJsonDateTime.validate,
+    # )
     
     # pre-experiment
     # ---------------------------------------------------------------------- #
@@ -232,7 +233,7 @@ class PlatformJson(pydantic.BaseModel):
     
     manipulator_coordinates: Dict[str, Dict[Any, Any]] = pydantic.Field(default_factory=dict)
 
-    files: Dict[str, Dict[str, Dict[str, List]]] = pydantic.Field(default_factory=dict)
+    files: Dict[str, Dict[str, str]] = pydantic.Field(default_factory=dict)
 
     def update(self, field, new) -> None:
         
@@ -264,7 +265,8 @@ def update_from_session(pj: PlatformJson, session) -> None:
         pj.update('stimulus_name', session.lims['stimulus_name'])
         if pj.script_name:
             with contextlib.suppress(Exception):
-                pj.update('script_name', np_config.local_to_unc(session.rig.stim, pj.script_name))
+                if session.rig.stim not in pj.script_name.as_posix():
+                    pj.update('script_name', np_config.local_to_unc(session.rig.stim, pj.script_name).as_posix())
         pj.update('foraging_id', session.foraging_id)
         pj.update('project', session.project.id)
         pj.update('hab', session.is_hab)
