@@ -1,4 +1,4 @@
 from np_session.databases.data_getters import *
 from np_session.databases.lims2 import *
 from np_session.databases.mtrain import *
-from np_session.databases.redis import State
+from np_session.databases.firebase_state import State
